@@ -9,16 +9,21 @@ import java.util.Locale;
 import javax.swing.ImageIcon;
 import javax.swing.JFrame;
 import javax.swing.JLabel;
+import javax.swing.JScrollPane;
 import javax.swing.JSplitPane;
 
 import org.af.commons.Localizer;
 import org.mutoss.config.Configuration;
+import org.mutoss.gui.datatable.CellEditorE;
+import org.mutoss.gui.datatable.CellValue;
+import org.mutoss.gui.datatable.DataFramePanel;
+import org.mutoss.gui.datatable.DataTable;
+import org.mutoss.gui.datatable.RDataFrameRef;
 import org.mutoss.gui.graph.ControlMGraph;
 import org.mutoss.gui.graph.GraphMCP;
 import org.mutoss.gui.graph.GraphView;
 import org.mutoss.gui.graph.PView;
 
-
 public class CreateGraphGUI extends JFrame implements WindowListener {
 	
 	GraphMCP graph;
@@ -68,11 +73,15 @@ public class CreateGraphGUI extends JFrame implements WindowListener {
 	GraphView graphview;
 	ControlMGraph agc;
 	PView pview;
+	DataFramePanel dfp;
 	
 	private void makeContent() {
 		graphview = new GraphView(agc);
 		pview = new PView(agc);
-		JSplitPane splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, graphview, pview);
+		dfp = new DataFramePanel(new RDataFrameRef());
+		dfp.getTable().setDefaultEditor(CellValue.class, new CellEditorE(agc));
+		JSplitPane splitPane2 = new JSplitPane(JSplitPane.VERTICAL_SPLIT, new JScrollPane(dfp), pview);
+		JSplitPane splitPane = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, graphview, splitPane2);
 		this.getContentPane().add(splitPane);		
 	}
 
@@ -95,4 +104,8 @@ public class CreateGraphGUI extends JFrame implements WindowListener {
 	public GraphView getGraphView() {		
 		return graphview;
 	}
+
+	public DataTable getDataTable() {		
+		return dfp.getTable();
+	}
 }
