@@ -4,7 +4,7 @@ import javax.swing.JLabel;
 
 import org.af.jhlir.backends.rengine.RCallServicesREngine;
 import org.mutoss.gui.RControl;
-import org.mutoss.gui.graph.AbstractGraphControl;
+import org.mutoss.gui.graph.ControlMGraph;
 import org.mutoss.gui.graph.GraphMCP;
 import org.mutoss.gui.graph.NetzListe;
 import org.mutoss.gui.graph.VS;
@@ -14,7 +14,7 @@ public class TestImportExport {
 	public TestImportExport(String graph1, String graph2) {
 		RControl.getRControl(true);
 		VS vs = new VS();
-		vs.nl = new NetzListe(new JLabel(""), vs, new AbstractGraphControl(graph1, null));
+		vs.nl = new NetzListe(new JLabel(""), vs, new ControlMGraph(graph1, null));
 		GraphMCP jGraph = new GraphMCP(graph1, vs);
 		jGraph.getNL().saveGraph(graph2, false);
 	}
